@@ -11,10 +11,10 @@ urlpatterns = [
          name='comments-xtd-api-create'),
     path('preview/', preview_user_avatar,
          name='comments-xtd-api-preview'),
-    re_path(r'^(?P<content_type>\w+[-]{1}\w+)/(?P<object_pk>[-\w]+)/$',
+    re_path(r'^(?P<content_type>\w+-\w+)/(?P<object_pk>[-\w]+)/$',
             CommentList.as_view(), name='comments-xtd-api-list'),
     re_path(
-        r'^(?P<content_type>\w+[-]{1}\w+)/(?P<object_pk>[-\w]+)/count/$',
+        r'^(?P<content_type>\w+-\w+)/(?P<object_pk>[-\w]+)/count/$',
         CommentCount.as_view(), name='comments-xtd-api-count'),
     path('feedback/', ToggleFeedbackFlag.as_view(),
          name='comments-xtd-api-feedback'),
