@@ -12,7 +12,7 @@ class PublicManager(models.Manager):
     """Returns published articles that are not in the future."""
 
     def published(self):
-        return self.get_query_set().filter(publish__lte=datetime.now())
+        return self.get_queryset().filter(publish__lte=datetime.now())
 
 
 class Article(models.Model):
@@ -51,6 +51,13 @@ class Diary(models.Model):
         db_table = 'demo_diary'
         ordering = ('-publish',)
 
+    def get_absolute_url(self):
+        return reverse(
+            'diary-detail',
+            kwargs={'year': self.publish.year,
+                    'month': int(self.publish.strftime('%m').lower()),
+                    'day': self.publish.day})
+
 
 class UUIDDiary(Diary):
     """Diary, that accepts comments."""
