@@ -1,7 +1,6 @@
 from __future__ import unicode_literals
 
 import os
-import imp
 
 
 PRJ_PATH = os.path.abspath(os.path.curdir)
@@ -88,17 +87,13 @@ TEMPLATES = [
             'context_processors': [
                 'django.template.context_processors.debug',
                 'django.template.context_processors.request',
-            ]
+            ],
+            # needed for django_coverage_plugin
+            'debug': True,
         }
     }
 ]
 
-try:
-    imp.find_module('django_comments')
-    django_comments = 'django_comments'
-except ImportError:
-    django_comments = 'django.contrib.comments'
-
 INSTALLED_APPS = [
     'django.contrib.auth',
     'django.contrib.contenttypes',
@@ -109,7 +104,7 @@ INSTALLED_APPS = [
 
     'django_comments_xtd',
     'django_comments_xtd.tests',
-    django_comments,
+    'django_comments',
 ]
 COMMENTS_APP = "django_comments_xtd"
 
@@ -134,7 +129,7 @@ REST_FRAMEWORK = {
     'DEFAULT_AUTHENTICATION_CLASSES': [
         'rest_framework.authentication.SessionAuthentication',
         'django_comments_xtd.tests.apiauth.APIRequestAuthentication'
-   ]
+    ]
 }
 
 TEST_RUNNER = 'django.test.runner.DiscoverRunner'
